@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict
 
-from .literals import ChangesetStatus, ChangeType, ErrorCategory, FormatType
+from .literals import ChangesetStatusType, ChangeTypeType, ErrorCategoryType, FormatTypeType
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -42,13 +42,13 @@ ChangesetInfoTypeDef = TypedDict(
         "id": str,
         "changesetArn": str,
         "datasetId": str,
-        "changeType": ChangeType,
+        "changeType": ChangeTypeType,
         "sourceType": Literal["S3"],
         "sourceParams": Dict[str, str],
-        "formatType": FormatType,
+        "formatType": FormatTypeType,
         "formatParams": Dict[str, str],
         "createTimestamp": datetime,
-        "status": ChangesetStatus,
+        "status": ChangesetStatusType,
         "errorInfo": "ErrorInfoTypeDef",
         "changesetLabels": Dict[str, str],
         "updatesChangesetId": str,
@@ -79,7 +79,7 @@ ErrorInfoTypeDef = TypedDict(
     "ErrorInfoTypeDef",
     {
         "errorMessage": str,
-        "errorCategory": ErrorCategory,
+        "errorCategory": ErrorCategoryType,
     },
     total=False,
 )
